==> haskell-time-compat-1.9.6.1-97-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-compat
version:              1.9.6.1
visibility:           public
id:                   time-compat-1.9.6.1-4LKUUS0AewnA698ITHrhN1
key:                  time-compat-1.9.6.1-4LKUUS0AewnA698ITHrhN1
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  55633a910a77fd7b246bd6df17c1cf5a
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.2.8/site-local/time-compat-1.9.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/time-compat-1.9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-compat
hs-libraries:         HStime-compat-1.9.6.1-4LKUUS0AewnA698ITHrhN1
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-9SrFWHJupRo443OOwuTGTo
    deepseq-1.4.6.1 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-compat-1.9.6.1-99.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 time-compat
version:              1.9.6.1
visibility:           public
id:                   time-compat-1.9.6.1-Cd4ZO0rf1QSALzCGMKTb3h
key:                  time-compat-1.9.6.1-Cd4ZO0rf1QSALzCGMKTb3h
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  dbfb747fad54a874e5590514ec9cd8ec
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.2.8/site-local/time-compat-1.9.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/time-compat-1.9.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-compat
hs-libraries:         HStime-compat-1.9.6.1-Cd4ZO0rf1QSALzCGMKTb3h
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW
    deepseq-1.4.6.1 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
